#include "alarmwindow.h"
#include "ui_alarmwindow.h"

#if  defined(Q_WS_MAEMO_5)
#include <QtDBus/QtDBus>
#include <time.h>
#include <alarm_dbus.h>
#include <libalarm.h>
#endif

//#include <QLocale>
#include "settingsdialog.h"
#include "nalarmsettings.h"

#define alarmIconPath "/usr/share/icons/hicolor/48x48/hildon/general_alarm_on.png"
#define clockIconPath "/usr/share/icons/hicolor/48x48/hildon/general_clock.png"
#define recurIconPath "/usr/share/icons/hicolor/48x48/hildon/general_refresh.png"

static int fntAdd = 3;
//static int iconWidth = 30;
static int nextPeriod = 86400; // look forward for 24 hours

AlarmWindow::AlarmWindow(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::AlarmWindow)
{
    ui->setupUi(this);
    setAttribute(Qt::WA_TranslucentBackground);
    resize(300,300);

    loadSettings();
    fillAlarmList();
    updateUi();
}

AlarmWindow::~AlarmWindow()
{
    delete ui;
}

void AlarmWindow::fillAlarmList()
{
#if  defined(Q_WS_MAEMO_5)
    QIcon icn (alarmIconPath);
    QIcon icnRecur (recurIconPath);
#else
    QIcon icn ("d:\\Qt\\Project\\NextAlarm\\hicolor\\18x18\\hildon\\general_alarm_on.png");
#endif

    ui->listWidget->clear();
    QFontMetrics fm(m_font);
    int fntHeight = fm.height() + fntAdd;

    if (m_showCaption)
    {
       QString header;
       header = QString(tr("alarms in next %1 h").arg(QString::number(86400/3600)));
       QListWidgetItem * item = new QListWidgetItem;
       item->setText(header);
       item->setTextAlignment(Qt::AlignBottom);
       QFont hFnt;
       hFnt.setUnderline(true);
//       QIcon icnClock (clockIconPath);
//       item->setIcon(icnClock);
       item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
       item->setFont(hFnt);
       ui->listWidget->addItem(item);
    }

#if  defined(Q_WS_MAEMO_5)
    cookie_t *list, *iter;
    time_t now;

    now = time(NULL);
    list = alarmd_event_query(now, now + nextPeriod, ALARM_EVENT_DISABLED, 0, NULL);
    if (list == NULL) {
            fprintf(stderr, "alarm_event_query() failed\n");
    }

    bool aFound = false;
    if (list[0] != (cookie_t) 0) {
            for (iter = list; *iter != (cookie_t) 0; iter++) {

                QListWidgetItem * item = new QListWidgetItem;
                item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
                item->setForeground(m_color);
                item->setFont(m_font);

                    alarm_event_t * aevent = alarmd_event_get (*iter);
                    int recur = alarm_event_is_recurring (aevent);
                    bool toAdd = false;
                    time_t ttime;
                    if (recur > 0)
                    {
                        if (aevent->recurrence_cnt > 0)
                        {
                            toAdd = true;
                            alarm_recur_t* arecur = &aevent->recurrence_tab[0];
                            const char* tz = alarm_event_get_alarm_tz(aevent);
                            struct tm* rtm = localtime(&now);
                            ttime = alarm_recur_next(arecur,rtm,tz);
                            item->setIcon(icnRecur);
                        }
                    }
                    else
                    {
                        toAdd = true;
                        struct tm* rtm = localtime(&now);
                        struct tm atm;
                        alarm_event_get_time (aevent,&atm);
                        rtm->tm_hour = atm.tm_hour;
                        rtm->tm_min = atm.tm_min;
                        ttime = mktime(rtm);
                        item->setIcon(icn);
                    }
                    if (toAdd)
                    {
                        aFound = true;
                        const char * cTitle = alarm_event_get_message(aevent);
                        QString aTitle (QString::fromUtf8(cTitle));
                        QDateTime qdtm = QDateTime::fromTime_t(ttime);
                        QTime qtm = qdtm.time();
                        QString sTime = qtm.toString(Qt::DefaultLocaleShortDate);
                        if (!aTitle.isEmpty())
                            sTime = sTime + " (" + aTitle + ")";
                        item->setText(sTime);
                        ui->listWidget->addItem(item);
                    }
            }
    }
    free(list);
    if (!aFound) // now alarms
    {
        QListWidgetItem * item = new QListWidgetItem;
        item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
        item->setForeground(m_color);
        item->setFont(m_font);
        item->setText(tr("no active alarms"));
        ui->listWidget->addItem(item);
    }
#else
    for (int i = 0; i < 5; i++)
    {
        QListWidgetItem * item = new QListWidgetItem;
        item->setIcon(icn);
        item->setText(QString("%1:%2").arg(QString::number(12)).arg(QString::number(15+i)));
        ui->listWidget->addItem(item);
    }
#endif
}

void AlarmWindow::showClock()
{
#if  defined(Q_WS_MAEMO_5)
    QDBusConnection bus = QDBusConnection::sessionBus();
    QDBusInterface dbus_iface("com.nokia.HildonDesktop.AppMgr", "/com/nokia/HildonDesktop/AppMgr",
                          "com.nokia.HildonDesktop.AppMgr", bus);
    dbus_iface.call("LaunchApplication","worldclock");
#endif
}


void AlarmWindow::mouseReleaseEvent ( QMouseEvent * e )
{
    Q_UNUSED(e);
    //test Dialogs
    showClock();
}

void AlarmWindow::listClicked()
{
    showClock();
}

void AlarmWindow::showSettingsDialog()
    {
    SettingsDialog dialog(0);
    if (dialog.exec() == QDialog::Accepted) {

        dialog.dumpSettings();
        loadSettings();
    }
}

void AlarmWindow::loadSettings()
{
    m_color = nalarmsettings::getInstance().getColor();
    m_numberAlarms = nalarmsettings::getInstance().getSize();
    m_width = nalarmsettings::getInstance().getWidth();
    m_font = nalarmsettings::getInstance().getFont();
    m_showCaption = nalarmsettings::getInstance().showHeader();
}

void AlarmWindow::homeScreenChanged(bool isOnCurrentHomescreen)
{
    if (isOnCurrentHomescreen)
    {
        fillAlarmList();
        updateUi();    }
    //TODO update display
}

void AlarmWindow::updateUi()
{
    int x = geometry().x();
    int y = geometry().y();
    int listHeight;
    QFontMetrics fm(m_font);
    int fntHeight = fm.height() + fntAdd;
    if (m_showCaption)
    {
        listHeight = ((m_numberAlarms + 1) * (fntHeight) + 20);
    }
    else
        listHeight = ((m_numberAlarms) * (fntHeight)+20);
    ui->listWidget->setIconSize(QSize(fntHeight/2,fntHeight/2));
    setGeometry(x,y,m_width,listHeight);
}
